leaftools.copy_written_duration_and_multiplier_from_leaf_to_leaf
================================================================

.. autofunction:: abjad.tools.leaftools.copy_written_duration_and_multiplier_from_leaf_to_leaf.copy_written_duration_and_multiplier_from_leaf_to_leaf
